@@ -26,7 +26,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-$Id: LimitsOld.pm 3400 2010-03-02 20:06:03Z mha $
+$Id: LimitsOld.pm 4130 2011-01-20 15:51:37Z jo $
 
 =end comment
 
@@ -250,7 +250,7 @@ sub get_full_group_path {
     my $parent     = munin_get_parent($group);
     my $name       = get_notify_name($group);
 
-    if (defined $parent and munin_get_node_name($parent) ne "root") {
+    if (defined $parent and munin_get_node_name($parent) ne "#%#root") {
 	return (get_full_group_path($parent) . " :: " . $name);
     } else {
 	return $name;
@@ -480,29 +480,35 @@ sub get_limits {
     if (defined $crit and $crit =~ /^\s*([-+\d.]*):([-+\d.]*)\s*$/) {
         $critical[0] = $1 if length $1;
         $critical[1] = $2 if length $2;
-        DEBUG "[DEBUG] processing critical: $name -> $critical[0] : $critical[1]";
     }
     elsif (defined $crit and $crit =~ /^\s*([-+\d.]+)\s*$/) {
-        $critical[1] = $1 if defined $1;
-        DEBUG "[DEBUG] processing critical: $name -> : $critical[1]";
+        $critical[1] = $1;
     }
     elsif (defined $crit) {
         @critical = (0, 0);
-        DEBUG "[DEBUG] processing critical: $name -> $critical[0] : $critical[1]";
     }
+    if(defined $crit) {
+        DEBUG "[DEBUG] processing critical: $name -> "
+                . (defined $critical[0]? $critical[0] : "")
+                .  " : "
+                . (defined $critical[1]? $critical[1] : "");
+    }   
 
     if (defined $warn and $warn =~ /^\s*([-+\d.]*):([-+\d.]*)\s*$/) {
         $warning[0] = $1 if length $1;
         $warning[1] = $2 if length $2;
-        DEBUG "[DEBUG] processing warning: $name -> $warning[0] : $warning[1]";
     }
     elsif (defined $warn and $warn =~ /^\s*([-+\d.]+)\s*$/) {
-        $warning[1] = $1 if defined $1;
-        DEBUG "[DEBUG] processing warning: $name -> : $warning[1]";
+        $warning[1] = $1;
     }
     elsif (defined $warn) {
         @warning = (0, 0);
-        DEBUG "[DEBUG] processing warning: $name -> $warning[0] : $warning[1]";
+    }
+    if(defined $warn) {
+        DEBUG "[DEBUG] processing warning: $name -> "
+                . (defined $warning[0]? $warning[0] : "")
+                .  " : "
+                . (defined $warning[1]? $warning[1] : "");
     }
 
     if ($unknown_limit =~ /^\s*(\d+)\s*$/) {
@@ -700,6 +706,8 @@ sub generate_service_message {
         }
         DEBUG "[DEBUG] sending message: \"$txt\"";
         print $pipe $txt, "\n" if (defined $pipe);
+        DEBUG "[DEBUG] explicitely closing pipe as suggested by schamane on #732";
+        close $pipe if (defined $pipe);
         $contactobj->{"num_messages"}
             = 1 + munin_get($contactobj, "num_messages", 0);   # $num_messages++
     }
@@ -712,12 +720,18 @@ sub message_expand {
     my @res  = ();
 
 
-    while (length($text)) {
+    while (defined($text) && length($text)) {
         if ($text =~ /^([^\$]+|)(?:\$(\{.*)|)$/) {
             push @res, $1;
             $text = $2;
         }
+
         my @a = extract_bracketed($text, '{}');
+        if(!defined $a[0]) {
+            $text = $a[1];
+            next;
+        }
+
         if ($a[0] =~ /^\{var:(\S+)\}$/) {
             $a[0] = munin_get($hash, $1, "");
         }
@@ -761,8 +775,8 @@ sub message_expand {
             my $t     = $3;
             my $res   = "";
             my $field = munin_get($hash, $f, 0);
-            my $check = ($field ne "0" and length($field));
-            $check = (!length($field) or $field eq "0") if $n;
+            my $check = (defined $field and $field ne "0" and length($field));
+            $check = (!$check) if $n;
 
             if ($check) {
                 $res .= message_expand($hash, $t);
