@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
-# $Id: Plugin.pm 3253 2009-12-23 10:03:36Z janl $
+# $Id: Plugin.pm 3955 2010-10-11 23:46:31Z bldewolf $
 #
 
 package Munin::Plugin;
@@ -60,7 +60,7 @@ our @ISA = ('Exporter');
 our @EXPORT = qw(
         clean_fieldname
         set_state_name save_state restore_state
-        get_thresholds print_thresholds
+        get_thresholds print_thresholds adjust_threshold
         tail_open tail_close
         scaleNumber
         need_multigraph
@@ -370,6 +370,22 @@ sub print_thresholds {
     print "$field.critical $critical\n" if defined($critical);
 }
 
+=head3 adjust_threshold($threshold, $base)
+
+If $threshold contains % signs, return a new threshold with adjusted values for
+these percentages against $base.
+
+=cut
+
+sub adjust_threshold {
+    my ($threshold, $base) = @_;
+
+    return undef if(!defined $threshold or !defined $base);
+
+    $threshold =~ s!(\d+\.?\d*)%!$1*$base/100!eg;
+
+    return $threshold;
+}
 
 =head3 ($file_handle,$rotated) = tail_open($file_name, $position)
 
