@@ -24,7 +24,7 @@
 # pattern.  Please maintain it in the same way.
 
 
-# $Id: SNMP.pm 3558 2010-05-05 17:02:43Z ligne $
+# $Id: SNMP.pm 3868 2010-08-19 09:19:37Z mha $
 
 =head1 NAME
 
@@ -477,7 +477,7 @@ sub get_single {
 
         my $response = $handle->get_request($oid);
 
-        if (!defined $response->{$oid} or $handle->error_status) {
+        if (!defined $response->{$oid} or $handle->error_status or $response->{$oid} eq 'noSuchObject') {
             print STDERR "# Error getting $oid: ",$handle->error(),"\n"
                 if $DEBUG;
             return;
